Changelog
=========


1.0a2 (2017-04-26)
------------------

- Do not send expiration email if there are no users with deadlines
  that expired before our search-date [fRiSi]


1.0a1 (2017-04-26)
------------------

- Initial release.
  [frisi]
